You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [27/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ ma...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/MixedParamUrlCodingStrategyTest.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request.target.coding;
+package org.apache.wicket.request.target.coding;
 
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.request.target.coding.MixedParamUrlCodingStrategy;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.tester.WicketTester;
+import org.apache.wicket.util.value.ValueMap;
+
 import junit.framework.TestCase;
-import wicket.markup.html.WebPage;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.tester.WicketTester;
-import wicket.util.value.ValueMap;
 
 /**
  * Tests for {@link MixedParamUrlCodingStrategy}.
@@ -47,7 +49,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap1()
 	{
@@ -68,7 +70,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap2()
 	{
@@ -91,7 +93,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap3()
 	{
@@ -120,7 +122,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap4()
 	{
@@ -137,7 +139,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap5()
 	{
@@ -157,7 +159,7 @@
 
 	/**
 	 * Test method for
-	 * {@link MixedParamUrlCodingStrategy#appendParameters(wicket.util.string.AppendingStringBuffer, java.util.Map)}.
+	 * {@link MixedParamUrlCodingStrategy#appendParameters(org.apache.wicket.util.string.AppendingStringBuffer, java.util.Map)}.
 	 */
 	public void testAppendParametersAppendingStringBufferMap6()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/PackageRequestTargetUrlCodingStrategyTest.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request.target.coding;
+package org.apache.wicket.request.target.coding;
+
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.request.target.coding.IRequestTargetUrlCodingStrategy;
+import org.apache.wicket.util.lang.PackageName;
+import org.apache.wicket.util.tester.WicketTester;
 
 import junit.framework.TestCase;
-import wicket.WicketRuntimeException;
-import wicket.util.lang.PackageName;
-import wicket.util.tester.WicketTester;
 
 /**
  * Tests package resources.
@@ -84,7 +86,7 @@
 		catch (WicketRuntimeException e)
 		{
 			assertEquals(
-					"Unable to load class with name: wicket.request.target.coding.nonexistent.TestPage",
+					"Unable to load class with name: org.apache.wicket.request.target.coding.nonexistent.TestPage",
 					e.getMessage());
 		}
 	}

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/TestPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/TestPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/TestPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/TestPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/TestPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/request/target/coding/TestPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/request/target/coding/TestPage.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.request.target.coding;
+package org.apache.wicket.request.target.coding;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * Simple dummy page.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ApplicationStringResourceLoaderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ApplicationStringResourceLoaderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ApplicationStringResourceLoaderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ApplicationStringResourceLoaderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ApplicationStringResourceLoaderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ApplicationStringResourceLoaderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ApplicationStringResourceLoaderTest.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 import java.util.Locale;
 
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.resource.loader.ClassStringResourceLoader;
+import org.apache.wicket.resource.loader.IStringResourceLoader;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.Assert;
-import wicket.protocol.http.WebApplication;
-import wicket.resource.loader.ClassStringResourceLoader;
-import wicket.resource.loader.IStringResourceLoader;
-import wicket.util.tester.WicketTester;
 
 /**
  * Tests for the <code>ApplicationStringResourceLoader</code> class.
@@ -50,7 +51,7 @@
 	}
 
 	/**
-	 * @see wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
+	 * @see org.apache.wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
 	 */
 	public void testLoaderUnknownResources()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/BundleStringResourceLoaderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/BundleStringResourceLoaderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/BundleStringResourceLoaderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/BundleStringResourceLoaderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/BundleStringResourceLoaderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/BundleStringResourceLoaderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/BundleStringResourceLoaderTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 import java.util.Locale;
 
+import org.apache.wicket.resource.loader.BundleStringResourceLoader;
+import org.apache.wicket.resource.loader.IStringResourceLoader;
+
 import junit.framework.Assert;
-import wicket.resource.loader.BundleStringResourceLoader;
-import wicket.resource.loader.IStringResourceLoader;
 
 /**
  * Test case for the <code>BundleStringResourceLoader</code> class.
@@ -44,11 +45,11 @@
 	 */
 	protected IStringResourceLoader createLoader()
 	{
-		return new BundleStringResourceLoader("wicket.resource.DummyResources");
+		return new BundleStringResourceLoader("org.apache.wicket.resource.DummyResources");
 	}
 
 	/**
-	 * @see wicket.resource.StringResourceLoaderTestBase#testLoaderValidKeyStyleNoLocale()
+	 * @see org.apache.wicket.resource.StringResourceLoaderTestBase#testLoaderValidKeyStyleNoLocale()
 	 */
 	public void testLoaderValidKeyStyleNoLocale()
 	{
@@ -57,7 +58,7 @@
 	}
 
 	/**
-	 * @see wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
+	 * @see org.apache.wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
 	 */
 	public void testLoaderUnknownResources()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ComponentStringResourceLoaderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ComponentStringResourceLoaderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ComponentStringResourceLoaderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ComponentStringResourceLoaderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ComponentStringResourceLoaderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/ComponentStringResourceLoaderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/ComponentStringResourceLoaderTest.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 import java.util.Locale;
 
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.html.panel.Panel;
+import org.apache.wicket.resource.loader.ComponentStringResourceLoader;
+import org.apache.wicket.resource.loader.IStringResourceLoader;
+
 import junit.framework.Assert;
-import wicket.Component;
-import wicket.markup.html.panel.Panel;
-import wicket.resource.loader.ComponentStringResourceLoader;
-import wicket.resource.loader.IStringResourceLoader;
 
 /**
  * Test case for the <code>ComponentStringResourceLoader</code> class.
@@ -49,7 +50,7 @@
 	}
 
 	/**
-	 * @see wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
+	 * @see org.apache.wicket.resource.StringResourceLoaderTestBase#testLoaderUnknownResources()
 	 */
 	public void testLoaderUnknownResources()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyApplication.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyApplication.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyApplication.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyApplication.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyApplication.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyApplication.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyApplication.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 import javax.servlet.http.HttpServletResponse;
 
-import wicket.protocol.http.WebApplication;
-import wicket.protocol.http.WebResponse;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.protocol.http.WebResponse;
+
 
 /**
  * Dummy application used for resource loader testing.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyComponent.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyComponent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyComponent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyComponent.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyComponent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyComponent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyComponent.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
-import wicket.Application;
-import wicket.Component;
-import wicket.markup.MarkupStream;
+import org.apache.wicket.Application;
+import org.apache.wicket.Component;
+import org.apache.wicket.markup.MarkupStream;
 
 /**
  * Dummy component used for testing or resource loading funationality.
@@ -44,7 +44,7 @@
 
 	/**
 	 * 
-	 * @see wicket.Component#onRender(wicket.markup.MarkupStream)
+	 * @see org.apache.wicket.Component#onRender(org.apache.wicket.markup.MarkupStream)
 	 */
 	protected void onRender(final MarkupStream markupStream)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummyPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummyPage.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  * Dummy page used for resource testing.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummySubClassPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummySubClassPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummySubClassPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummySubClassPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummySubClassPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/DummySubClassPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/DummySubClassPage.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 /**
  * Dummy subclass page used for resource testing.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/InvalidResourceSpecificationExceptionTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/InvalidResourceSpecificationExceptionTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/InvalidResourceSpecificationExceptionTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/InvalidResourceSpecificationExceptionTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/InvalidResourceSpecificationExceptionTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/InvalidResourceSpecificationExceptionTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/InvalidResourceSpecificationExceptionTest.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
+
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.ExceptionTestBase;
 
-import wicket.WicketRuntimeException;
-import wicket.util.ExceptionTestBase;
 
 /**
  * Unit tests for the <code>InvalidResourceSpecificationException</code>.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/StringResourceLoaderTestBase.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/StringResourceLoaderTestBase.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/StringResourceLoaderTestBase.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/StringResourceLoaderTestBase.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/StringResourceLoaderTestBase.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/resource/StringResourceLoaderTestBase.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/resource/StringResourceLoaderTestBase.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.resource;
+package org.apache.wicket.resource;
 
 import java.util.Locale;
 
+import org.apache.wicket.Component;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.resource.loader.IStringResourceLoader;
+import org.apache.wicket.util.tester.WicketTester;
+
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import wicket.Component;
-import wicket.protocol.http.WebApplication;
-import wicket.resource.loader.IStringResourceLoader;
-import wicket.util.tester.WicketTester;
 
 /**
  * Abstract base class providing common test functionality to ensure that all loader

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/session/DefaultPageFactoryTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/session/DefaultPageFactoryTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/session/DefaultPageFactoryTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/session/DefaultPageFactoryTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/session/DefaultPageFactoryTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/session/DefaultPageFactoryTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/session/DefaultPageFactoryTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.session;
+package org.apache.wicket.session;
+
+import org.apache.wicket.AbstractRestartResponseException;
+import org.apache.wicket.IPageFactory;
+import org.apache.wicket.Page;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.session.DefaultPageFactory;
 
-import wicket.AbstractRestartResponseException;
-import wicket.IPageFactory;
-import wicket.Page;
-import wicket.PageParameters;
-import wicket.WicketTestCase;
 
 /**
  * Default page facotry tests

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentPage.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentPage.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentPage.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.stateless;
+package org.apache.wicket.stateless;
 
-import wicket.WicketRuntimeException;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.link.StatelessLink;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.link.StatelessLink;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/stateless/StatelessComponentTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/stateless/StatelessComponentTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.stateless;
+package org.apache.wicket.stateless;
 
-import wicket.WicketTestCase;
+import org.apache.wicket.WicketTestCase;
 
 /**
  * @author jcompagner
@@ -46,7 +46,7 @@
 		tester
 				.getServletRequest()
 				.setURL(
-						"?wicket:bookmarkablePage=:wicket.stateless.StatelessComponentPage&wicket:interface=:0:link::ILinkListener:");
+						"?org.apache.wicket:bookmarkablePage=:org.apache.wicket.stateless.StatelessComponentPage&org.apache.wicket:interface=:0:link::ILinkListener:");
 		try
 		{
 			tester.processRequestCycle();
@@ -70,7 +70,7 @@
 		// "StatelessComponentPage_mount_result.html");
 		tester.setupRequestAndResponse();
 		tester.getServletRequest().setURL(
-				"/stateless/wicket:interface/:0:link::ILinkListener:");
+				"/stateless/org.apache.wicket:interface/:0:link::ILinkListener:");
 		try
 		{
 			tester.processRequestCycle();

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/ExceptionTestBase.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/ExceptionTestBase.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/ExceptionTestBase.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/ExceptionTestBase.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/ExceptionTestBase.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/ExceptionTestBase.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/ExceptionTestBase.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util;
+package org.apache.wicket.util;
 
 import java.lang.reflect.Constructor;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MicroMapTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MicroMapTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MicroMapTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MicroMapTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MicroMapTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MicroMapTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MicroMapTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.collections;
+package org.apache.wicket.util.collections;
 
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
+
+import org.apache.wicket.util.collections.MicroMap;
 
 import junit.framework.TestCase;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MiniMapTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MiniMapTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MiniMapTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MiniMapTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MiniMapTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/collections/MiniMapTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/collections/MiniMapTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.collections;
+package org.apache.wicket.util.collections;
 
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
+
+import org.apache.wicket.util.collections.MiniMap;
 
 import junit.framework.TestCase;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/convert/converters/ConvertersTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/convert/converters/ConvertersTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/convert/converters/ConvertersTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/convert/converters/ConvertersTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/convert/converters/ConvertersTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/convert/converters/ConvertersTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/convert/converters/ConvertersTest.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.convert.converters;
+package org.apache.wicket.util.convert.converters;
 
 import java.util.Calendar;
 import java.util.Date;
 import java.util.Locale;
 
+import org.apache.wicket.IConverterLocator;
+import org.apache.wicket.util.convert.ConversionException;
+import org.apache.wicket.util.convert.ConverterLocator;
+import org.apache.wicket.util.convert.converters.BooleanConverter;
+import org.apache.wicket.util.convert.converters.ByteConverter;
+import org.apache.wicket.util.convert.converters.DateConverter;
+import org.apache.wicket.util.convert.converters.DoubleConverter;
+import org.apache.wicket.util.convert.converters.FloatConverter;
+import org.apache.wicket.util.convert.converters.IntegerConverter;
+import org.apache.wicket.util.convert.converters.LongConverter;
+import org.apache.wicket.util.convert.converters.ShortConverter;
+
 import junit.framework.TestCase;
-import wicket.IConverterLocator;
-import wicket.util.convert.ConversionException;
-import wicket.util.convert.ConverterLocator;
 
 /**
  * Tests for the base converters.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/crypt/Base64Test.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/crypt/Base64Test.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/crypt/Base64Test.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/crypt/Base64Test.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/crypt/Base64Test.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/crypt/Base64Test.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/crypt/Base64Test.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.crypt;
+package org.apache.wicket.util.crypt;
 
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.Random;
 
+import org.apache.wicket.settings.ISecuritySettings;
+import org.apache.wicket.util.crypt.Base64;
+import org.apache.wicket.util.crypt.Base64UrlSafe;
+import org.apache.wicket.util.crypt.CachingSunJceCryptFactory;
+import org.apache.wicket.util.crypt.ICrypt;
+import org.apache.wicket.util.crypt.NoCrypt;
+
 import junit.framework.TestCase;
-import wicket.settings.ISecuritySettings;
 
 /**
  * 
@@ -62,7 +68,7 @@
 	 */
 	public void test_1a() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
 
 		byte[] s = new Base64().encode(input.getBytes());
 
@@ -77,7 +83,7 @@
 	 */
 	public void test_1b() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerA";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerA";
 
 		byte[] s = new Base64().encode(input.getBytes());
 
@@ -92,7 +98,7 @@
 	 */
 	public void test_1c() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerAB";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerAB";
 
 		byte[] s = new Base64().encode(input.getBytes());
 
@@ -107,7 +113,7 @@
 	 */
 	public void test_1d() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerABC";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerABC";
 
 		byte[] s = new Base64().encode(input.getBytes());
 
@@ -134,7 +140,7 @@
 	 */
 	public void test_3() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
 		ICrypt crypt = new CachingSunJceCryptFactory(ISecuritySettings.DEFAULT_ENCRYPTION_KEY)
 				.newCrypt();
 		String s = crypt.encryptUrlSafe(input);
@@ -166,7 +172,7 @@
 	 */
 	public void test_UrlSafe_1a() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
 
 		byte[] s = new Base64UrlSafe().encode(input.getBytes());
 
@@ -181,7 +187,7 @@
 	 */
 	public void test_UrlSafe_1b() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerA";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerA";
 
 		byte[] s = new Base64UrlSafe().encode(input.getBytes());
 
@@ -196,7 +202,7 @@
 	 */
 	public void test_UrlSafe_1c() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerAB";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerAB";
 
 		byte[] s = new Base64UrlSafe().encode(input.getBytes());
 
@@ -211,7 +217,7 @@
 	 */
 	public void test_UrlSafe_1d() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerABC";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListenerABC";
 
 		byte[] s = new Base64UrlSafe().encode(input.getBytes());
 
@@ -238,7 +244,7 @@
 	 */
 	public void test_UrlSafe_3() throws IOException
 	{
-		String input = "wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
+		String input = "org.apache.wicket:interface=:2:entityTree:node:node:0:node:nodeLink::IBehaviorListener";
 		ICrypt crypt = new CachingSunJceCryptFactory(ISecuritySettings.DEFAULT_ENCRYPTION_KEY)
 				.newCrypt();
 		String s = crypt.encryptUrlSafe(input);

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/WicketOutputStreamTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/WicketOutputStreamTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/WicketOutputStreamTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/WicketOutputStreamTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/WicketOutputStreamTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/WicketOutputStreamTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/WicketOutputStreamTest.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.io;
+package org.apache.wicket.util.io;
 
 import java.io.ByteArrayInputStream;
 import java.math.BigInteger;
 import java.util.GregorianCalendar;
 
+import org.apache.wicket.util.io.ByteArrayOutputStream;
+import org.apache.wicket.util.io.WicketObjectInputStream;
+import org.apache.wicket.util.io.WicketObjectOutputStream;
+
 import junit.framework.Assert;
 import junit.framework.TestCase;
 
@@ -89,8 +93,8 @@
 	// public void testStringsEqualsAfterSerialization() throws Exception
 	// {
 	// String[] strings = new String[2];
-	// strings[0] = new String("wicket");
-	// strings[1] = "wicket";
+	// strings[0] = new String("org.apache.wicket");
+	// strings[1] = "org.apache.wicket";
 	//		
 	// assertEquals(false, strings[0] == strings[1]);
 	//		

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/XmlReaderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/XmlReaderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/XmlReaderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/XmlReaderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/XmlReaderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/io/XmlReaderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/io/XmlReaderTest.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.io;
+package org.apache.wicket.util.io;
 
 import java.io.BufferedReader;
+
+import org.apache.wicket.util.io.XmlReader;
 
 import junit.framework.TestCase;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Address.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Address.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Address.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Address.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Address.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Address.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Address.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/BytesTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/BytesTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/BytesTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/BytesTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/BytesTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/BytesTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/BytesTest.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 import java.util.Locale;
 
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.string.StringValueConversionException;
+
 import junit.framework.TestCase;
-import wicket.util.string.StringValueConversionException;
 
 /**
  * Tests the <code>Bytes</code> class.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Country.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Country.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Country.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Country.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Country.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Country.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Country.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/ObjectsTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/ObjectsTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/ObjectsTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/ObjectsTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/ObjectsTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 import java.util.ArrayList;
 import java.util.List;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person2.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 /**
  * @author jcompagner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PrimitivesTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PrimitivesTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PrimitivesTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PrimitivesTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PrimitivesTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PrimitivesTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PrimitivesTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
+
+import org.apache.wicket.util.lang.Primitives;
 
 import junit.framework.TestCase;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PropertyResolverTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PropertyResolverTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PropertyResolverTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PropertyResolverTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PropertyResolverTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/PropertyResolverTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/PropertyResolverTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -22,10 +22,13 @@
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.convert.ConversionException;
+import org.apache.wicket.util.convert.ConverterLocator;
+import org.apache.wicket.util.lang.PropertyResolver;
+import org.apache.wicket.util.lang.PropertyResolverConverter;
+
 import junit.framework.TestCase;
-import wicket.WicketRuntimeException;
-import wicket.util.convert.ConversionException;
-import wicket.util.convert.ConverterLocator;
 
 /**
  * @author jcompagner
@@ -54,9 +57,9 @@
 		String name = (String)PropertyResolver.getValue("name", person);
 		assertNull(name);
 
-		PropertyResolver.setValue("name", person, "wicket", CONVERTER);
+		PropertyResolver.setValue("name", person, "org.apache.wicket", CONVERTER);
 		name = (String)PropertyResolver.getValue("name", person);
-		assertEquals(name, "wicket");
+		assertEquals(name, "org.apache.wicket");
 	}
 
 	/**
@@ -88,9 +91,9 @@
 	public void testPathExpression() throws Exception
 	{
 		person.setAddress(new Address());
-		PropertyResolver.setValue("address.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("address.street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("address.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 
 	}
 
@@ -108,9 +111,9 @@
 	 */
 	public void testNullCreation() throws Exception
 	{
-		PropertyResolver.setValue("address.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("address.street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("address.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 
 		try
 		{
@@ -169,9 +172,9 @@
 		Address address = new Address();
 		PropertyResolver.setValue("addressMap", person, new HashMap(), CONVERTER);
 		PropertyResolver.setValue("addressMap.address", person, address, CONVERTER);
-		PropertyResolver.setValue("addressMap.address.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressMap.address.street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("addressMap.address.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 	}
 
 	/**
@@ -183,12 +186,12 @@
 		PropertyResolver.setValue("addressList.0", person, new Address(), CONVERTER);
 		PropertyResolver.setValue("addressList.10", person, new Address(), CONVERTER);
 		PropertyResolver.setValue("addressList.1", person, new Address(), CONVERTER);
-		PropertyResolver.setValue("addressList.1.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressList.1.street", person, "org.apache.wicket-street", CONVERTER);
 
 		String street = (String)PropertyResolver.getValue("addressList.0.street", person);
 		assertNull(street);
 		street = (String)PropertyResolver.getValue("addressList.1.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 	}
 
 	/**
@@ -198,13 +201,13 @@
 	{
 		PropertyResolver.setValue("addressArray", person, new Address[] { new Address(), null },
 				CONVERTER);
-		PropertyResolver.setValue("addressArray.0.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressArray.0.street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("addressArray.0.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 
-		PropertyResolver.setValue("addressArray.1.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressArray.1.street", person, "org.apache.wicket-street", CONVERTER);
 		street = (String)PropertyResolver.getValue("addressArray.1.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 	}
 
 	/**
@@ -214,13 +217,13 @@
 	{
 		PropertyResolver.setValue("addressArray", person, new Address[] { new Address(), null },
 				CONVERTER);
-		PropertyResolver.setValue("addressArray[0].street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressArray[0].street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("addressArray[0].street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 
-		PropertyResolver.setValue("addressArray[1].street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressArray[1].street", person, "org.apache.wicket-street", CONVERTER);
 		street = (String)PropertyResolver.getValue("addressArray[1].street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 	}
 
 	/**
@@ -229,9 +232,9 @@
 	public void testPropertyByIndexLookup() throws Exception
 	{
 		PropertyResolver.setValue("addressAt.0", person, new Address(), CONVERTER);
-		PropertyResolver.setValue("addressAt.0.street", person, "wicket-street", CONVERTER);
+		PropertyResolver.setValue("addressAt.0.street", person, "org.apache.wicket-street", CONVERTER);
 		String street = (String)PropertyResolver.getValue("addressAt.0.street", person);
-		assertEquals(street, "wicket-street");
+		assertEquals(street, "org.apache.wicket-street");
 	}
 
 	/**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/license/ApacheLicenceHeaderTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/license/ApacheLicenceHeaderTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/license/ApacheLicenceHeaderTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/license/ApacheLicenceHeaderTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/license/ApacheLicenceHeaderTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/license/ApacheLicenceHeaderTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/license/ApacheLicenceHeaderTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.license;
+package org.apache.wicket.util.license;
+
+import org.apache.wicket.util.license.ApacheLicenseHeaderTestCase;
 
 /**
  * Test that the license headers are in place in this project. The tests are run
@@ -41,7 +43,7 @@
 				/*
 				 * See NOTICE.txt
 				 */
-				"src/main/java/wicket/util/diff",				
+				"src/main/java/org.apache.wicket/util/diff",				
 		};
 		
 		cssIgnore = new String[] {
@@ -61,29 +63,29 @@
 				/*
 				 * ASL1.1. Taken from Maven JRCS. See NOTICE.txt
 				 */
-				"src/main/java/wicket/util/diff/AddDelta.java",
-				"src/main/java/wicket/util/diff/ChangeDelta.java",
-				"src/main/java/wicket/util/diff/Chunk.java",
-				"src/main/java/wicket/util/diff/DeleteDelta.java",
-				"src/main/java/wicket/util/diff/Delta.java",
-				"src/main/java/wicket/util/diff/Diff.java",
-				"src/main/java/wicket/util/diff/DiffAlgorithm.java",
-				"src/main/java/wicket/util/diff/DifferentiationFailedException.java",
-				"src/main/java/wicket/util/diff/DiffException.java",
-				"src/main/java/wicket/util/diff/PatchFailedException.java",
-				"src/main/java/wicket/util/diff/Revision.java",
-				"src/main/java/wicket/util/diff/RevisionVisitor.java",
-				"src/main/java/wicket/util/diff/ToString.java",
-				"src/main/java/wicket/util/diff/myers/DiffNode.java",
-				"src/main/java/wicket/util/diff/myers/MyersDiff.java",
-				"src/main/java/wicket/util/diff/myers/PathNode.java",
-				"src/main/java/wicket/util/diff/myers/Snake.java",
+				"src/main/java/org.apache.wicket/util/diff/AddDelta.java",
+				"src/main/java/org.apache.wicket/util/diff/ChangeDelta.java",
+				"src/main/java/org.apache.wicket/util/diff/Chunk.java",
+				"src/main/java/org.apache.wicket/util/diff/DeleteDelta.java",
+				"src/main/java/org.apache.wicket/util/diff/Delta.java",
+				"src/main/java/org.apache.wicket/util/diff/Diff.java",
+				"src/main/java/org.apache.wicket/util/diff/DiffAlgorithm.java",
+				"src/main/java/org.apache.wicket/util/diff/DifferentiationFailedException.java",
+				"src/main/java/org.apache.wicket/util/diff/DiffException.java",
+				"src/main/java/org.apache.wicket/util/diff/PatchFailedException.java",
+				"src/main/java/org.apache.wicket/util/diff/Revision.java",
+				"src/main/java/org.apache.wicket/util/diff/RevisionVisitor.java",
+				"src/main/java/org.apache.wicket/util/diff/ToString.java",
+				"src/main/java/org.apache.wicket/util/diff/myers/DiffNode.java",
+				"src/main/java/org.apache.wicket/util/diff/myers/MyersDiff.java",
+				"src/main/java/org.apache.wicket/util/diff/myers/PathNode.java",
+				"src/main/java/org.apache.wicket/util/diff/myers/Snake.java",
 				/*
 				 * Needs to be resolved (rewritten or NOTICE)
 				 */
-				"src/main/java/wicket/util/concurrent/ConcurrentReaderHashMap.java",
-				"src/main/java/wicket/util/concurrent/ConcurrentHashMap.java",
-				"src/main/java/wicket/util/concurrent/CopyOnWriteArrayList.java"
+				"src/main/java/org.apache.wicket/util/concurrent/ConcurrentReaderHashMap.java",
+				"src/main/java/org.apache.wicket/util/concurrent/ConcurrentHashMap.java",
+				"src/main/java/org.apache.wicket/util/concurrent/CopyOnWriteArrayList.java"
 		};
 		
 		javaScriptIgnore = new String[] { 
@@ -97,8 +99,8 @@
 				/*
 				 * See NOTICE.txt
 				 */
-				"src/main/java/wicket/ajax/wicket-ajax-debug-drag.js",
-				"src/main/java/wicket/markup/html/form/upload/MultiFileUploadField.js"
+				"src/main/java/org.apache.wicket/ajax/org.apache.wicket-ajax-debug-drag.js",
+				"src/main/java/org.apache.wicket/markup/html/form/upload/MultiFileUploadField.js"
 		};
 		
 		propertiesIgnore = new String[] {

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/MetaPatternTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/MetaPatternTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/MetaPatternTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/MetaPatternTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/MetaPatternTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/MetaPatternTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/MetaPatternTest.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.parse.metapattern;
+package org.apache.wicket.util.parse.metapattern;
 
 
 import java.util.regex.Matcher;
 
+import org.apache.wicket.util.parse.metapattern.Group;
+import org.apache.wicket.util.parse.metapattern.IntegerGroup;
+import org.apache.wicket.util.parse.metapattern.MetaPattern;
+import org.apache.wicket.util.parse.metapattern.parsers.CommaSeparatedVariableParser;
+import org.apache.wicket.util.parse.metapattern.parsers.IntegerVariableAssignmentParser;
+import org.apache.wicket.util.parse.metapattern.parsers.TagNameParser;
+import org.apache.wicket.util.parse.metapattern.parsers.VariableAssignmentParser;
+
 import junit.framework.TestCase;
-import wicket.util.parse.metapattern.parsers.CommaSeparatedVariableParser;
-import wicket.util.parse.metapattern.parsers.IntegerVariableAssignmentParser;
-import wicket.util.parse.metapattern.parsers.TagNameParser;
-import wicket.util.parse.metapattern.parsers.VariableAssignmentParser;
 
 /**
  * Test cases for this object

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/IndexedParamTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/IndexedParamTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/IndexedParamTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/IndexedParamTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/IndexedParamTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/IndexedParamTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/IndexedParamTest.java Tue Apr 10 11:15:14 2007
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.parse.metapattern.parsers;
+package org.apache.wicket.util.parse.metapattern.parsers;
+
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.protocol.http.MockHttpServletRequest;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.request.target.coding.IndexedParamUrlCodingStrategy;
+import org.apache.wicket.util.diff.DiffUtil;
 
-import wicket.WicketTestCase;
-import wicket.protocol.http.MockHttpServletRequest;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.request.target.coding.IndexedParamUrlCodingStrategy;
-import wicket.util.diff.DiffUtil;
 
 /**
- * Test [ 1470093 ] <wicket:link> does not accept numeric param names
+ * Test [ 1470093 ] <org.apache.wicket:link> does not accept numeric param names
  * 
  * @author Juergen Donnerstag
  * @author Blake Day 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page1.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page1.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page1.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page1.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page1.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page1.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page1.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.parse.metapattern.parsers;
+package org.apache.wicket.util.parse.metapattern.parsers;
 
-import wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.WebPage;
 
 /**
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page2.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page2.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page2.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page2.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page2.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/parse/metapattern/parsers/Page2.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/parse/metapattern/parsers/Page2.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.parse.metapattern.parsers;
+package org.apache.wicket.util.parse.metapattern.parsers;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.PageParameters;
+import org.apache.wicket.markup.html.WebPage;
 
-import wicket.PageParameters;
-import wicket.markup.html.WebPage;
 
 /**
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/resource/ResourceTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/resource/ResourceTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/resource/ResourceTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/resource/ResourceTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/resource/ResourceTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/resource/ResourceTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/resource/ResourceTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.resource;
+package org.apache.wicket.util.resource;
 
 import java.io.File;
 import java.net.URI;
@@ -22,12 +22,15 @@
 import java.net.URL;
 import java.util.Locale;
 
+import org.apache.wicket.util.file.Folder;
+import org.apache.wicket.util.file.Path;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.resource.UrlResourceStream;
+import org.apache.wicket.util.resource.locator.IResourceStreamLocator;
+import org.apache.wicket.util.resource.locator.ResourceStreamLocator;
+import org.apache.wicket.util.string.Strings;
+
 import junit.framework.TestCase;
-import wicket.util.file.Folder;
-import wicket.util.file.Path;
-import wicket.util.resource.locator.IResourceStreamLocator;
-import wicket.util.resource.locator.ResourceStreamLocator;
-import wicket.util.string.Strings;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/size/BytesTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/size/BytesTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/size/BytesTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/size/BytesTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/size/BytesTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/size/BytesTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/size/BytesTest.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.size;
+package org.apache.wicket.util.size;
 
 
 import java.util.Locale;
 
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.string.StringValueConversionException;
+
 import junit.framework.Assert;
 import junit.framework.TestCase;
-import wicket.util.lang.Bytes;
-import wicket.util.string.StringValueConversionException;
 
 /**
  * Test cases for this object

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/AppendingStringBufferTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/AppendingStringBufferTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/AppendingStringBufferTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/AppendingStringBufferTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/AppendingStringBufferTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/AppendingStringBufferTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/AppendingStringBufferTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.string;
+package org.apache.wicket.util.string;
+
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
 import junit.framework.TestCase;
 
@@ -25,7 +27,7 @@
 {
 
 	/**
-	 * Test method for 'wicket.util.string.AppendingStringBuffer.append(String)'
+	 * Test method for 'org.apache.wicket.util.string.AppendingStringBuffer.append(String)'
 	 */
 	public void testAppend()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/PrependingStringBufferTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/PrependingStringBufferTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/PrependingStringBufferTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/PrependingStringBufferTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/PrependingStringBufferTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/PrependingStringBufferTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/PrependingStringBufferTest.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.string;
+package org.apache.wicket.util.string;
+
+import org.apache.wicket.util.string.PrependingStringBuffer;
 
 import junit.framework.TestCase;
 
@@ -25,7 +27,7 @@
 {
 
 	/**
-	 * Test method for 'wicket.util.string.PrependingStringBuffer.prepend(String)'
+	 * Test method for 'org.apache.wicket.util.string.PrependingStringBuffer.prepend(String)'
 	 */
 	public void testPrepend()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringListTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringListTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringListTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringListTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringListTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringListTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringListTest.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.string;
+package org.apache.wicket.util.string;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+
+import org.apache.wicket.util.string.StringList;
 
 import junit.framework.TestCase;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringsTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringsTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringsTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringsTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringsTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/StringsTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/StringsTest.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.string;
+package org.apache.wicket.util.string;
 
 import java.io.UnsupportedEncodingException;
 
-import wicket.WicketRuntimeException;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.StringValueConversionException;
+import org.apache.wicket.util.string.Strings;
+
 
 import junit.framework.Assert;
 import junit.framework.TestCase;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/interpolator/VariableInterpolatorTest.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/interpolator/VariableInterpolatorTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/interpolator/VariableInterpolatorTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/interpolator/VariableInterpolatorTest.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/interpolator/VariableInterpolatorTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/string/interpolator/VariableInterpolatorTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/string/interpolator/VariableInterpolatorTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.string.interpolator;
+package org.apache.wicket.util.string.interpolator;
 
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.wicket.util.string.interpolator.MapVariableInterpolator;
+
 import junit.framework.TestCase;
-import wicket.util.string.interpolator.MapVariableInterpolator;
 
 /**
  * Tests {@link MapVariableInterpolator}

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/BlockedResourceLinkPage.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/BlockedResourceLinkPage.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/BlockedResourceLinkPage.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/BlockedResourceLinkPage.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/BlockedResourceLinkPage.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/BlockedResourceLinkPage.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/BlockedResourceLinkPage.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.tester;
+package org.apache.wicket.util.tester;
 
-import wicket.ResourceReference;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.link.ResourceLink;
+import org.apache.wicket.ResourceReference;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.link.ResourceLink;
 
 /**
  * Mock page for testing WicketTesters ability to test ResourceLinks

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/FormTesterTest.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/FormTesterTest.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/FormTesterTest.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/FormTesterTest.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/FormTesterTest.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/ObjectsTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/ObjectsTest.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.lang;
+package org.apache.wicket.util.lang;
 
 import java.io.Serializable;
 
-import wicket.WicketTestCase;
-import wicket.markup.html.form.TextField;
-import wicket.model.Model;
-import wicket.model.PropertyModel;
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.TextField;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.model.PropertyModel;
+import org.apache.wicket.util.lang.Objects;
+
 
 /**
  * Tests the Objects class.
@@ -42,7 +44,7 @@
 	}
 
 	/**
 	 * Test method for 'wicket.util.lang.Objects.equal(Object, Object)'
 	 */
 	public void testEqual()
 	{
@@ -62,7 +64,7 @@
 	}
 
 	/**
 	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneNull()
 	{
@@ -71,7 +73,7 @@
 	}
 
 	/**
 	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneString()
 	{
@@ -83,7 +85,7 @@
 	}
 
 	/**
 	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneObject()
 	{
@@ -112,7 +114,7 @@
 	}
 
 	/**
 	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneCloneObject()
 	{
@@ -42,7 +44,7 @@
 
 	/**
-	 * Test method for 'wicket.util.lang.Objects.equal(Object, Object)'
+	 * Test method for 'org.apache.wicket.util.lang.Objects.equal(Object, Object)'
 	 */
 	public void testEqual()
@@ -62,7 +64,7 @@
 
 	/**
-	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
+	 * Test method for 'org.apache.wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneNull()
@@ -71,7 +73,7 @@
 
 	/**
-	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
+	 * Test method for 'org.apache.wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneString()
@@ -83,7 +85,7 @@
 
 	/**
-	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
+	 * Test method for 'org.apache.wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneObject()
@@ -112,7 +114,7 @@
 
 	/**
-	 * Test method for 'wicket.util.lang.Objects.clone(Object)'
+	 * Test method for 'org.apache.wicket.util.lang.Objects.clone(Object)'
 	 */
 	public void testCloneCloneObject()

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/lang/Person.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/lang/Person.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/wicket/util/tester/FormTesterTest.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/test/java/org/apache/wicket/util/tester/FormTesterTest.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.util.tester;
+package org.apache.wicket.util.tester;
+
+import org.apache.wicket.WicketTestCase;
+import org.apache.wicket.markup.html.form.upload.FileUpload;
+import org.apache.wicket.util.file.File;
+import org.apache.wicket.util.tester.FormTester;
+import org.apache.wicket.util.tester.MockFormFileUploadPage.MockDomainObjectFileUpload;
+import org.apache.wicket.util.tester.MockFormPage.MockDomainObject;
 
-import wicket.WicketTestCase;
-import wicket.markup.html.form.upload.FileUpload;
-import wicket.util.file.File;
-import wicket.util.tester.MockFormFileUploadPage.MockDomainObjectFileUpload;
-import wicket.util.tester.MockFormPage.MockDomainObject;
 
 /**
  * Test of FormTester.
@@ -65,7 +67,7 @@
 
 	/**
 	 * Test that the user can use
 	 * {@link FormTester#setFile(String, wicket.util.file.File, String)} to test
 	 * that upload to a FileUploadField works.
 	 */
 	public void testAddFile()
@@ -65,7 +67,7 @@
 	/**
 	 * Test that the user can use
-	 * {@link FormTester#setFile(String, wicket.util.file.File, String)} to test
+	 * {@link FormTester#setFile(String, org.apache.wicket.util.file.File, String)} to test
 	 * that upload to a FileUploadField works.
 	 */